ECDHKeyDerivator class
Methods
deriveKey (Uint8List inp , int inpOff , Uint8List out , int outOff )
→ int
Derive key from given input and put it in out at offset outOff.
override
init (covariant ECDHKDFParameters params )
→ void
Init the derivator with its initialization params. The type of CipherParameters depends on the algorithm being used
(see the documentation of each implementation to find out more).
override
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process (Uint8List data )
→ Uint8List
Process a whole block of data at once, returning the result in a byte array.
inherited
toString ()
→ String
A string representation of this object.
inherited
pointycastle_broadcom 4.0.1